from near_jsonrpc_models.error_wrapper_for_rpc_state_changes_error import ErrorWrapperForRpcStateChangesError
from near_jsonrpc_models.rpc_state_changes_in_block_response import RpcStateChangesInBlockResponse
from pydantic import BaseModel
from pydantic import RootModel
from typing import Union


class JsonRpcResponseForRpcStateChangesInBlockResponseAndRpcStateChangesErrorResult(BaseModel):
    id: str
    jsonrpc: str
    result: RpcStateChangesInBlockResponse

class JsonRpcResponseForRpcStateChangesInBlockResponseAndRpcStateChangesErrorError(BaseModel):
    id: str
    jsonrpc: str
    error: ErrorWrapperForRpcStateChangesError

class JsonRpcResponseForRpcStateChangesInBlockResponseAndRpcStateChangesError(RootModel[Union[JsonRpcResponseForRpcStateChangesInBlockResponseAndRpcStateChangesErrorResult, JsonRpcResponseForRpcStateChangesInBlockResponseAndRpcStateChangesErrorError]]):
    pass




"""A shard layout that maps accounts evenly across all shards -- by calculate the hash of account
id and mod number of shards. This is added to capture the old `account_id_to_shard_id` algorithm,
to keep backward compatibility for some existing tests.
`parent_shards` for `ShardLayoutV1` is always `None`, meaning it can only be the first shard layout
a chain uses."""

from pydantic import BaseModel
from pydantic import conint


class ShardLayoutV0(BaseModel):
    # Map accounts evenly across all shards
    num_shards: conint(ge=0, le=18446744073709551615)
    # Version of the shard layout, this is useful for uniquely identify the shard layout
    version: conint(ge=0, le=4294967295)



"""Information about a Producer: its account name, peer_id and a list of connected peers that
the node can use to send message for this producer."""

from near_jsonrpc_models.account_id import AccountId
from near_jsonrpc_models.public_key import PublicKey
from pydantic import BaseModel
from typing import List


class KnownProducerView(BaseModel):
    account_id: AccountId
    next_hops: List[PublicKey] | None = None
    peer_id: PublicKey



from near_jsonrpc_models.near_gas import NearGas
from near_jsonrpc_models.near_token import NearToken
from pydantic import BaseModel


class FunctionCallAction(BaseModel):
    args: str
    deposit: NearToken
    gas: NearGas
    method_name: str



from near_jsonrpc_models.account_id import AccountId
from near_jsonrpc_models.block_id import BlockId
from near_jsonrpc_models.finality import Finality
from near_jsonrpc_models.public_key import PublicKey
from near_jsonrpc_models.sync_checkpoint import SyncCheckpoint
from pydantic import BaseModel
from pydantic import RootModel
from typing import Union


class RpcViewGasKeyRequestBlockId(BaseModel):
    account_id: AccountId
    public_key: PublicKey
    block_id: BlockId

class RpcViewGasKeyRequestFinality(BaseModel):
    account_id: AccountId
    public_key: PublicKey
    finality: Finality

class RpcViewGasKeyRequestSyncCheckpoint(BaseModel):
    account_id: AccountId
    public_key: PublicKey
    sync_checkpoint: SyncCheckpoint

class RpcViewGasKeyRequest(RootModel[Union[RpcViewGasKeyRequestBlockId, RpcViewGasKeyRequestFinality, RpcViewGasKeyRequestSyncCheckpoint]]):
    pass




from near_jsonrpc_models.internal_error import InternalError
from near_jsonrpc_models.rpc_light_client_proof_error import RpcLightClientProofError
from near_jsonrpc_models.rpc_request_validation_error_kind import RpcRequestValidationErrorKind
from pydantic import BaseModel
from pydantic import RootModel
from typing import Literal
from typing import Union


class ErrorWrapperForRpcLightClientProofErrorRequestValidationError(BaseModel):
    cause: RpcRequestValidationErrorKind
    name: Literal['REQUEST_VALIDATION_ERROR']

class ErrorWrapperForRpcLightClientProofErrorHandlerError(BaseModel):
    cause: RpcLightClientProofError
    name: Literal['HANDLER_ERROR']

class ErrorWrapperForRpcLightClientProofErrorInternalError(BaseModel):
    cause: InternalError
    name: Literal['INTERNAL_ERROR']

class ErrorWrapperForRpcLightClientProofError(RootModel[Union[ErrorWrapperForRpcLightClientProofErrorRequestValidationError, ErrorWrapperForRpcLightClientProofErrorHandlerError, ErrorWrapperForRpcLightClientProofErrorInternalError]]):
    pass




from near_jsonrpc_models.crypto_hash import CryptoHash
from near_jsonrpc_models.epoch_id import EpochId
from pydantic import BaseModel
from pydantic import conint


class StatusSyncInfo(BaseModel):
    earliest_block_hash: CryptoHash | None = None
    earliest_block_height: conint(ge=0, le=18446744073709551615) | None = None
    earliest_block_time: str | None = None
    epoch_id: EpochId | None = None
    epoch_start_height: conint(ge=0, le=18446744073709551615) | None = None
    latest_block_hash: CryptoHash
    latest_block_height: conint(ge=0, le=18446744073709551615)
    latest_block_time: str
    latest_state_root: CryptoHash
    syncing: bool



"""Describes the permission scope for an access key. Whether it is a function call or a full access key."""

from near_jsonrpc_models.near_token import NearToken
from near_jsonrpc_models.strict_model import StrictBaseModel
from pydantic import BaseModel
from pydantic import RootModel
from pydantic import conint
from typing import List
from typing import Literal
from typing import Union


class AccessKeyPermissionViewFullAccess(RootModel[Literal['FullAccess']]):
    pass

class AccessKeyPermissionViewFunctionCallPayload(BaseModel):
    allowance: NearToken | None = None
    method_names: List[str]
    receiver_id: str

class AccessKeyPermissionViewFunctionCall(StrictBaseModel):
    FunctionCall: AccessKeyPermissionViewFunctionCallPayload

class AccessKeyPermissionViewGasKeyFunctionCallPayload(BaseModel):
    allowance: NearToken | None = None
    balance: NearToken
    method_names: List[str]
    num_nonces: conint(ge=0, le=65535)
    receiver_id: str

class AccessKeyPermissionViewGasKeyFunctionCall(StrictBaseModel):
    GasKeyFunctionCall: AccessKeyPermissionViewGasKeyFunctionCallPayload

class AccessKeyPermissionViewGasKeyFullAccessPayload(BaseModel):
    balance: NearToken
    num_nonces: conint(ge=0, le=65535)

class AccessKeyPermissionViewGasKeyFullAccess(StrictBaseModel):
    GasKeyFullAccess: AccessKeyPermissionViewGasKeyFullAccessPayload

class AccessKeyPermissionView(RootModel[Union[AccessKeyPermissionViewFullAccess, AccessKeyPermissionViewFunctionCall, AccessKeyPermissionViewGasKeyFunctionCall, AccessKeyPermissionViewGasKeyFullAccess]]):
    pass




"""Describes the cost of creating an access key."""

from near_jsonrpc_models.fee import Fee
from pydantic import BaseModel


class AccessKeyCreationConfigView(BaseModel):
    # Base cost of creating a full access access-key.
    full_access_cost: Fee
    # Base cost of creating an access-key restricted to specific functions.
    function_call_cost: Fee
    # Cost per byte of method_names of creating a restricted access-key.
    function_call_cost_per_byte: Fee



from near_jsonrpc_models.internal_error import InternalError
from near_jsonrpc_models.rpc_request_validation_error_kind import RpcRequestValidationErrorKind
from near_jsonrpc_models.rpc_view_access_key_error import RpcViewAccessKeyError
from pydantic import BaseModel
from pydantic import RootModel
from typing import Literal
from typing import Union


class ErrorWrapperForRpcViewAccessKeyErrorRequestValidationError(BaseModel):
    cause: RpcRequestValidationErrorKind
    name: Literal['REQUEST_VALIDATION_ERROR']

class ErrorWrapperForRpcViewAccessKeyErrorHandlerError(BaseModel):
    cause: RpcViewAccessKeyError
    name: Literal['HANDLER_ERROR']

class ErrorWrapperForRpcViewAccessKeyErrorInternalError(BaseModel):
    cause: InternalError
    name: Literal['INTERNAL_ERROR']

class ErrorWrapperForRpcViewAccessKeyError(RootModel[Union[ErrorWrapperForRpcViewAccessKeyErrorRequestValidationError, ErrorWrapperForRpcViewAccessKeyErrorHandlerError, ErrorWrapperForRpcViewAccessKeyErrorInternalError]]):
    pass




from near_jsonrpc_models.internal_error import InternalError
from near_jsonrpc_models.rpc_query_error import RpcQueryError
from near_jsonrpc_models.rpc_request_validation_error_kind import RpcRequestValidationErrorKind
from pydantic import BaseModel
from pydantic import RootModel
from typing import Literal
from typing import Union


class ErrorWrapperForRpcQueryErrorRequestValidationError(BaseModel):
    cause: RpcRequestValidationErrorKind
    name: Literal['REQUEST_VALIDATION_ERROR']

class ErrorWrapperForRpcQueryErrorHandlerError(BaseModel):
    cause: RpcQueryError
    name: Literal['HANDLER_ERROR']

class ErrorWrapperForRpcQueryErrorInternalError(BaseModel):
    cause: InternalError
    name: Literal['INTERNAL_ERROR']

class ErrorWrapperForRpcQueryError(RootModel[Union[ErrorWrapperForRpcQueryErrorRequestValidationError, ErrorWrapperForRpcQueryErrorHandlerError, ErrorWrapperForRpcQueryErrorInternalError]]):
    pass




from near_jsonrpc_models.crypto_hash import CryptoHash
from near_jsonrpc_models.missing_trie_value_context import MissingTrieValueContext
from pydantic import BaseModel


class MissingTrieValue(BaseModel):
    context: MissingTrieValueContext
    hash: CryptoHash



from near_jsonrpc_models.account_id import AccountId
from near_jsonrpc_models.crypto_hash import CryptoHash
from near_jsonrpc_models.strict_model import StrictBaseModel
from pydantic import BaseModel
from pydantic import RootModel
from typing import Union


class GlobalContractIdentifierCodeHash(StrictBaseModel):
    CodeHash: CryptoHash

class GlobalContractIdentifierAccountId(StrictBaseModel):
    AccountId: AccountId

class GlobalContractIdentifier(RootModel[Union[GlobalContractIdentifierCodeHash, GlobalContractIdentifierAccountId]]):
    pass




"""Counterpart to `ShardLayoutV3` composed of maps with string keys to aid
serde serialization."""

from near_jsonrpc_models.account_id import AccountId
from near_jsonrpc_models.shard_id import ShardId
from pydantic import BaseModel
from pydantic import conint
from typing import Dict
from typing import List


class ShardLayoutV3(BaseModel):
    boundary_accounts: List[AccountId]
    id_to_index_map: Dict[str, conint(ge=0, le=4294967295)]
    last_split: ShardId
    shard_ids: List[ShardId]
    shards_split_map: Dict[str, List[ShardId]]



from near_jsonrpc_models.rpc_known_producer import RpcKnownProducer
from near_jsonrpc_models.rpc_peer_info import RpcPeerInfo
from pydantic import BaseModel
from pydantic import conint
from typing import List


class RpcNetworkInfoResponse(BaseModel):
    active_peers: List[RpcPeerInfo]
    # Accounts of known block and chunk producers from routing table.
    known_producers: List[RpcKnownProducer]
    num_active_peers: conint(ge=0, le=4294967295)
    peer_max_count: conint(ge=0, le=4294967295)
    received_bytes_per_sec: conint(ge=0, le=18446744073709551615)
    sent_bytes_per_sec: conint(ge=0, le=18446744073709551615)



from near_jsonrpc_models.public_key import PublicKey
from pydantic import BaseModel


class DeleteKeyAction(BaseModel):
    # A public key associated with the access_key to be deleted.
    public_key: PublicKey



from near_jsonrpc_models.epoch_id import EpochId
from pydantic import BaseModel
from pydantic import RootModel
from typing import Any
from typing import Dict
from typing import Literal
from typing import Union


class RpcLightClientNextBlockErrorInternalErrorInfo(BaseModel):
    error_message: str

class RpcLightClientNextBlockErrorInternalError(BaseModel):
    info: RpcLightClientNextBlockErrorInternalErrorInfo
    name: Literal['INTERNAL_ERROR']

class RpcLightClientNextBlockErrorUnknownBlock(BaseModel):
    info: Dict[str, Any]
    name: Literal['UNKNOWN_BLOCK']

class RpcLightClientNextBlockErrorEpochOutOfBoundsInfo(BaseModel):
    epoch_id: EpochId

class RpcLightClientNextBlockErrorEpochOutOfBounds(BaseModel):
    info: RpcLightClientNextBlockErrorEpochOutOfBoundsInfo
    name: Literal['EPOCH_OUT_OF_BOUNDS']

class RpcLightClientNextBlockError(RootModel[Union[RpcLightClientNextBlockErrorInternalError, RpcLightClientNextBlockErrorUnknownBlock, RpcLightClientNextBlockErrorEpochOutOfBounds]]):
    pass




"""`BandwidthRequest` describes the size of receipts that a shard would like to send to another shard.
When a shard wants to send a lot of receipts to another shard, it needs to create a request and wait
for a bandwidth grant from the bandwidth scheduler."""

from near_jsonrpc_models.bandwidth_request_bitmap import BandwidthRequestBitmap
from pydantic import BaseModel
from pydantic import conint


class BandwidthRequest(BaseModel):
    # Bitmap which describes what values of bandwidth are requested.
    requested_values_bitmap: BandwidthRequestBitmap
    # Requesting bandwidth to this shard.
    to_shard: conint(ge=0, le=65535)



from near_jsonrpc_models.error_wrapper_for_rpc_view_state_error import ErrorWrapperForRpcViewStateError
from near_jsonrpc_models.rpc_view_state_response import RpcViewStateResponse
from pydantic import BaseModel
from pydantic import RootModel
from typing import Union


class JsonRpcResponseForRpcViewStateResponseAndRpcViewStateErrorResult(BaseModel):
    id: str
    jsonrpc: str
    result: RpcViewStateResponse

class JsonRpcResponseForRpcViewStateResponseAndRpcViewStateErrorError(BaseModel):
    id: str
    jsonrpc: str
    error: ErrorWrapperForRpcViewStateError

class JsonRpcResponseForRpcViewStateResponseAndRpcViewStateError(RootModel[Union[JsonRpcResponseForRpcViewStateResponseAndRpcViewStateErrorResult, JsonRpcResponseForRpcViewStateResponseAndRpcViewStateErrorError]]):
    pass




from near_jsonrpc_models.error_wrapper_for_rpc_call_function_error import ErrorWrapperForRpcCallFunctionError
from near_jsonrpc_models.rpc_call_function_response import RpcCallFunctionResponse
from pydantic import BaseModel
from pydantic import RootModel
from typing import Union


class JsonRpcResponseForRpcCallFunctionResponseAndRpcCallFunctionErrorResult(BaseModel):
    id: str
    jsonrpc: str
    result: RpcCallFunctionResponse

class JsonRpcResponseForRpcCallFunctionResponseAndRpcCallFunctionErrorError(BaseModel):
    id: str
    jsonrpc: str
    error: ErrorWrapperForRpcCallFunctionError

class JsonRpcResponseForRpcCallFunctionResponseAndRpcCallFunctionError(RootModel[Union[JsonRpcResponseForRpcCallFunctionResponseAndRpcCallFunctionErrorResult, JsonRpcResponseForRpcCallFunctionResponseAndRpcCallFunctionErrorError]]):
    pass




from near_jsonrpc_models.error_wrapper_for_rpc_transaction_error import ErrorWrapperForRpcTransactionError
from near_jsonrpc_models.rpc_transaction_response import RpcTransactionResponse
from pydantic import BaseModel
from pydantic import RootModel
from typing import Union


class JsonRpcResponseForRpcTransactionResponseAndRpcTransactionErrorResult(BaseModel):
    id: str
    jsonrpc: str
    result: RpcTransactionResponse

class JsonRpcResponseForRpcTransactionResponseAndRpcTransactionErrorError(BaseModel):
    id: str
    jsonrpc: str
    error: ErrorWrapperForRpcTransactionError

class JsonRpcResponseForRpcTransactionResponseAndRpcTransactionError(RootModel[Union[JsonRpcResponseForRpcTransactionResponseAndRpcTransactionErrorResult, JsonRpcResponseForRpcTransactionResponseAndRpcTransactionErrorError]]):
    pass




"""Gas key is like an access key, except it stores a balance separately, and transactions signed
with it deduct their cost from the gas key balance instead of the account balance."""

from near_jsonrpc_models.access_key_permission import AccessKeyPermission
from near_jsonrpc_models.near_token import NearToken
from pydantic import BaseModel
from pydantic import conint


class GasKey(BaseModel):
    # The balance of the gas key.
    balance: NearToken
    # The number of nonces this gas key has.
    num_nonces: conint(ge=0, le=4294967295)
    # Defines the permissions for this gas key.
    # If this is a `FunctionCallPermission`, the allowance must be None (unlimited).
    permission: AccessKeyPermission



"""A view of the contract code."""

from near_jsonrpc_models.crypto_hash import CryptoHash
from pydantic import BaseModel
from pydantic import conint


class RpcViewCodeResponse(BaseModel):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)
    code_base64: str
    hash: CryptoHash



from near_jsonrpc_models.account_id import AccountId
from near_jsonrpc_models.block_reference import BlockReference
from near_jsonrpc_models.crypto_hash import CryptoHash
from pydantic import BaseModel
from pydantic import RootModel
from pydantic import conint
from typing import Literal
from typing import Union


class RpcViewAccountErrorUnknownBlockInfo(BaseModel):
    block_reference: BlockReference

class RpcViewAccountErrorUnknownBlock(BaseModel):
    info: RpcViewAccountErrorUnknownBlockInfo
    name: Literal['UNKNOWN_BLOCK']

class RpcViewAccountErrorInvalidAccountInfo(BaseModel):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)
    requested_account_id: AccountId

class RpcViewAccountErrorInvalidAccount(BaseModel):
    info: RpcViewAccountErrorInvalidAccountInfo
    name: Literal['INVALID_ACCOUNT']

class RpcViewAccountErrorUnknownAccountInfo(BaseModel):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)
    requested_account_id: AccountId

class RpcViewAccountErrorUnknownAccount(BaseModel):
    info: RpcViewAccountErrorUnknownAccountInfo
    name: Literal['UNKNOWN_ACCOUNT']

class RpcViewAccountErrorInternalErrorInfo(BaseModel):
    error_message: str

class RpcViewAccountErrorInternalError(BaseModel):
    info: RpcViewAccountErrorInternalErrorInfo
    name: Literal['INTERNAL_ERROR']

class RpcViewAccountError(RootModel[Union[RpcViewAccountErrorUnknownBlock, RpcViewAccountErrorInvalidAccount, RpcViewAccountErrorUnknownAccount, RpcViewAccountErrorInternalError]]):
    pass




from near_jsonrpc_models.gas_key_view import GasKeyView
from near_jsonrpc_models.public_key import PublicKey
from pydantic import BaseModel


class GasKeyInfoView(BaseModel):
    gas_key: GasKeyView
    public_key: PublicKey



"""Error returned in the ExecutionOutcome in case of failure"""

from near_jsonrpc_models.action_error import ActionError
from near_jsonrpc_models.invalid_tx_error import InvalidTxError
from near_jsonrpc_models.strict_model import StrictBaseModel
from pydantic import BaseModel
from pydantic import RootModel
from typing import Union


class TxExecutionErrorActionError(StrictBaseModel):
    """An error happened during Action execution"""
    ActionError: ActionError

class TxExecutionErrorInvalidTxError(StrictBaseModel):
    """An error happened during Transaction execution"""
    InvalidTxError: InvalidTxError

class TxExecutionError(RootModel[Union[TxExecutionErrorActionError, TxExecutionErrorInvalidTxError]]):
    pass




from near_jsonrpc_models.error_wrapper_for_rpc_receipt_error import ErrorWrapperForRpcReceiptError
from near_jsonrpc_models.rpc_receipt_response import RpcReceiptResponse
from pydantic import BaseModel
from pydantic import RootModel
from typing import Union


class JsonRpcResponseForRpcReceiptResponseAndRpcReceiptErrorResult(BaseModel):
    id: str
    jsonrpc: str
    result: RpcReceiptResponse

class JsonRpcResponseForRpcReceiptResponseAndRpcReceiptErrorError(BaseModel):
    id: str
    jsonrpc: str
    error: ErrorWrapperForRpcReceiptError

class JsonRpcResponseForRpcReceiptResponseAndRpcReceiptError(RootModel[Union[JsonRpcResponseForRpcReceiptResponseAndRpcReceiptErrorResult, JsonRpcResponseForRpcReceiptResponseAndRpcReceiptErrorError]]):
    pass




from near_jsonrpc_models.access_key_list import AccessKeyList
from near_jsonrpc_models.access_key_view import AccessKeyView
from near_jsonrpc_models.account_view import AccountView
from near_jsonrpc_models.call_result import CallResult
from near_jsonrpc_models.contract_code_view import ContractCodeView
from near_jsonrpc_models.crypto_hash import CryptoHash
from near_jsonrpc_models.gas_key_nonces_view import GasKeyNoncesView
from near_jsonrpc_models.view_state_result import ViewStateResult
from pydantic import BaseModel
from pydantic import RootModel
from pydantic import conint
from typing import Union


class RpcQueryResponseAccountView(AccountView):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)

class RpcQueryResponseContractCodeView(ContractCodeView):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)

class RpcQueryResponseViewStateResult(ViewStateResult):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)

class RpcQueryResponseCallResult(CallResult):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)

class RpcQueryResponseAccessKeyView(AccessKeyView):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)

class RpcQueryResponseAccessKeyList(AccessKeyList):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)

class RpcQueryResponseGasKeyNoncesView(GasKeyNoncesView):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)

class RpcQueryResponse(RootModel[Union[RpcQueryResponseAccountView, RpcQueryResponseContractCodeView, RpcQueryResponseViewStateResult, RpcQueryResponseCallResult, RpcQueryResponseAccessKeyView, RpcQueryResponseAccessKeyList, RpcQueryResponseGasKeyNoncesView]]):
    pass




"""Configuration for garbage collection."""

from near_jsonrpc_models.duration_as_std_schema_provider import DurationAsStdSchemaProvider
from pydantic import BaseModel
from pydantic import Field
from pydantic import conint


class GCConfig(BaseModel):
    # Maximum number of blocks to garbage collect at every garbage collection
    # call.
    gc_blocks_limit: conint(ge=0, le=18446744073709551615) = 2
    # Maximum number of height to go through at each garbage collection step
    # when cleaning forks during garbage collection.
    gc_fork_clean_step: conint(ge=0, le=18446744073709551615) = 100
    # Number of epochs for which we keep store data.
    gc_num_epochs_to_keep: conint(ge=0, le=18446744073709551615) = 5
    # How often gc should be run
    gc_step_period: DurationAsStdSchemaProvider = Field(default_factory=lambda: DurationAsStdSchemaProvider(**{'nanos': 500000000, 'secs': 0}))



"""It is a [serializable view] of [`StateChangesRequest`].

[serializable view]: ./index.html
[`StateChangesRequest`]: ../types/struct.StateChangesRequest.html"""

from near_jsonrpc_models.account_id import AccountId
from near_jsonrpc_models.account_with_public_key import AccountWithPublicKey
from near_jsonrpc_models.block_id import BlockId
from near_jsonrpc_models.finality import Finality
from near_jsonrpc_models.store_key import StoreKey
from near_jsonrpc_models.sync_checkpoint import SyncCheckpoint
from pydantic import BaseModel
from pydantic import RootModel
from typing import List
from typing import Literal
from typing import Union


class RpcStateChangesInBlockByTypeRequestAccountChangesByBlockId(BaseModel):
    block_id: BlockId
    account_ids: List[AccountId]
    changes_type: Literal['account_changes']

class RpcStateChangesInBlockByTypeRequestSingleAccessKeyChangesByBlockId(BaseModel):
    block_id: BlockId
    changes_type: Literal['single_access_key_changes']
    keys: List[AccountWithPublicKey]

class RpcStateChangesInBlockByTypeRequestAllAccessKeyChangesByBlockId(BaseModel):
    block_id: BlockId
    account_ids: List[AccountId]
    changes_type: Literal['all_access_key_changes']

class RpcStateChangesInBlockByTypeRequestContractCodeChangesByBlockId(BaseModel):
    block_id: BlockId
    account_ids: List[AccountId]
    changes_type: Literal['contract_code_changes']

class RpcStateChangesInBlockByTypeRequestDataChangesByBlockId(BaseModel):
    block_id: BlockId
    account_ids: List[AccountId]
    changes_type: Literal['data_changes']
    key_prefix_base64: StoreKey

class RpcStateChangesInBlockByTypeRequestAccountChangesByFinality(BaseModel):
    finality: Finality
    account_ids: List[AccountId]
    changes_type: Literal['account_changes']

class RpcStateChangesInBlockByTypeRequestSingleAccessKeyChangesByFinality(BaseModel):
    finality: Finality
    changes_type: Literal['single_access_key_changes']
    keys: List[AccountWithPublicKey]

class RpcStateChangesInBlockByTypeRequestAllAccessKeyChangesByFinality(BaseModel):
    finality: Finality
    account_ids: List[AccountId]
    changes_type: Literal['all_access_key_changes']

class RpcStateChangesInBlockByTypeRequestContractCodeChangesByFinality(BaseModel):
    finality: Finality
    account_ids: List[AccountId]
    changes_type: Literal['contract_code_changes']

class RpcStateChangesInBlockByTypeRequestDataChangesByFinality(BaseModel):
    finality: Finality
    account_ids: List[AccountId]
    changes_type: Literal['data_changes']
    key_prefix_base64: StoreKey

class RpcStateChangesInBlockByTypeRequestAccountChangesBySyncCheckpoint(BaseModel):
    sync_checkpoint: SyncCheckpoint
    account_ids: List[AccountId]
    changes_type: Literal['account_changes']

class RpcStateChangesInBlockByTypeRequestSingleAccessKeyChangesBySyncCheckpoint(BaseModel):
    sync_checkpoint: SyncCheckpoint
    changes_type: Literal['single_access_key_changes']
    keys: List[AccountWithPublicKey]

class RpcStateChangesInBlockByTypeRequestAllAccessKeyChangesBySyncCheckpoint(BaseModel):
    sync_checkpoint: SyncCheckpoint
    account_ids: List[AccountId]
    changes_type: Literal['all_access_key_changes']

class RpcStateChangesInBlockByTypeRequestContractCodeChangesBySyncCheckpoint(BaseModel):
    sync_checkpoint: SyncCheckpoint
    account_ids: List[AccountId]
    changes_type: Literal['contract_code_changes']

class RpcStateChangesInBlockByTypeRequestDataChangesBySyncCheckpoint(BaseModel):
    sync_checkpoint: SyncCheckpoint
    account_ids: List[AccountId]
    changes_type: Literal['data_changes']
    key_prefix_base64: StoreKey

class RpcStateChangesInBlockByTypeRequest(RootModel[Union[RpcStateChangesInBlockByTypeRequestAccountChangesByBlockId, RpcStateChangesInBlockByTypeRequestSingleAccessKeyChangesByBlockId, RpcStateChangesInBlockByTypeRequestAllAccessKeyChangesByBlockId, RpcStateChangesInBlockByTypeRequestContractCodeChangesByBlockId, RpcStateChangesInBlockByTypeRequestDataChangesByBlockId, RpcStateChangesInBlockByTypeRequestAccountChangesByFinality, RpcStateChangesInBlockByTypeRequestSingleAccessKeyChangesByFinality, RpcStateChangesInBlockByTypeRequestAllAccessKeyChangesByFinality, RpcStateChangesInBlockByTypeRequestContractCodeChangesByFinality, RpcStateChangesInBlockByTypeRequestDataChangesByFinality, RpcStateChangesInBlockByTypeRequestAccountChangesBySyncCheckpoint, RpcStateChangesInBlockByTypeRequestSingleAccessKeyChangesBySyncCheckpoint, RpcStateChangesInBlockByTypeRequestAllAccessKeyChangesBySyncCheckpoint, RpcStateChangesInBlockByTypeRequestContractCodeChangesBySyncCheckpoint, RpcStateChangesInBlockByTypeRequestDataChangesBySyncCheckpoint]]):
    pass




"""Describes the expected behavior of the node regarding shard tracking.
If the node is an active validator, it will also track the shards it is responsible for as a validator."""

from near_jsonrpc_models.account_id import AccountId
from near_jsonrpc_models.shard_id import ShardId
from near_jsonrpc_models.shard_uid import ShardUId
from near_jsonrpc_models.strict_model import StrictBaseModel
from pydantic import BaseModel
from pydantic import RootModel
from typing import List
from typing import Literal
from typing import Union


"""Tracks no shards (light client)."""
class TrackedShardsConfigNoShards(RootModel[Literal['NoShards']]):
    pass

class TrackedShardsConfigShards(StrictBaseModel):
    """Tracks arbitrary shards."""
    Shards: List[ShardUId]

"""Tracks all shards."""
class TrackedShardsConfigAllShards(RootModel[Literal['AllShards']]):
    pass

class TrackedShardsConfigShadowValidator(StrictBaseModel):
    """Tracks shards that are assigned to given validator account."""
    ShadowValidator: AccountId

class TrackedShardsConfigSchedule(StrictBaseModel):
    """Rotate between these sets of tracked shards.
Used to simulate the behavior of chunk only producers without staking tokens."""
    Schedule: List[List[ShardId]]

class TrackedShardsConfigAccounts(StrictBaseModel):
    """Tracks shards that contain one of the given account."""
    Accounts: List[AccountId]

class TrackedShardsConfig(RootModel[Union[TrackedShardsConfigNoShards, TrackedShardsConfigShards, TrackedShardsConfigAllShards, TrackedShardsConfigShadowValidator, TrackedShardsConfigSchedule, TrackedShardsConfigAccounts]]):
    pass




"""ClientConfig where some fields can be updated at runtime."""

from near_jsonrpc_models.chunk_distribution_network_config import ChunkDistributionNetworkConfig
from near_jsonrpc_models.cloud_archival_writer_config import CloudArchivalWriterConfig
from near_jsonrpc_models.epoch_sync_config import EpochSyncConfig
from near_jsonrpc_models.gcconfig import GCConfig
from near_jsonrpc_models.log_summary_style import LogSummaryStyle
from near_jsonrpc_models.mutable_config_value import MutableConfigValue
from near_jsonrpc_models.near_gas import NearGas
from near_jsonrpc_models.protocol_version_check_config import ProtocolVersionCheckConfig
from near_jsonrpc_models.state_sync_config import StateSyncConfig
from near_jsonrpc_models.tracked_shards_config import TrackedShardsConfig
from near_jsonrpc_models.version import Version
from pydantic import BaseModel
from pydantic import conint
from pydantic import conlist
from typing import List


class RpcClientConfigResponse(BaseModel):
    # Not clear old data, set `true` for archive nodes.
    archive: bool = None
    # Horizon at which instead of fetching block, fetch full state.
    block_fetch_horizon: conint(ge=0, le=18446744073709551615) = None
    # Behind this horizon header fetch kicks in.
    block_header_fetch_horizon: conint(ge=0, le=18446744073709551615) = None
    # Duration to check for producing / skipping block.
    block_production_tracking_delay: conlist(conint(ge=0, le=18446744073709551615), min_length=2, max_length=2) = None
    # Time between check to perform catchup.
    catchup_step_period: conlist(conint(ge=0, le=18446744073709551615), min_length=2, max_length=2) = None
    # Chain id for status.
    chain_id: str = None
    # Optional config for the Chunk Distribution Network feature.
    # If set to `None` then this node does not participate in the Chunk Distribution Network.
    # Nodes not participating will still function fine, but possibly with higher
    # latency due to the need of requesting chunks over the peer-to-peer network.
    chunk_distribution_network: ChunkDistributionNetworkConfig | None = None
    # Time between checking to re-request chunks.
    chunk_request_retry_period: conlist(conint(ge=0, le=18446744073709551615), min_length=2, max_length=2) = None
    # Number of threads for ChunkValidationActor pool.
    chunk_validation_threads: conint(ge=0, le=4294967295) = None
    # Multiplier for the wait time for all chunks to be received.
    chunk_wait_mult: conlist(conint(ge=-2147483648, le=2147483647), min_length=2, max_length=2) = None
    # Height horizon for the chunk cache. A chunk is removed from the cache
    # if its height + chunks_cache_height_horizon < largest_seen_height.
    # The default value is DEFAULT_CHUNKS_CACHE_HEIGHT_HORIZON.
    chunks_cache_height_horizon: conint(ge=0, le=18446744073709551615) = None
    # Number of threads to execute background migration work in client.
    client_background_migration_threads: conint(ge=0, le=4294967295) = None
    # Configuration for a cloud-based archival writer. If this config is present, the writer is enabled and
    # writes chunk-related data based on the tracked shards.
    cloud_archival_writer: CloudArchivalWriterConfig | None = None
    # If true, the node won't forward transactions to next the chunk producers.
    disable_tx_routing: bool = None
    # Time between running doomslug timer.
    doomslug_step_period: conlist(conint(ge=0, le=18446744073709551615), min_length=2, max_length=2) = None
    # If true, transactions for the next chunk will be prepared early, right after the previous chunk's
    # post-state is ready. This can help produce chunks faster, for high-throughput chains.
    # The current implementation increases latency on low-load chains, which will be fixed in the future.
    # The default is disabled.
    enable_early_prepare_transactions: bool = None
    enable_multiline_logging: bool = None
    # Re-export storage layer statistics as prometheus metrics.
    enable_statistics_export: bool = None
    # Epoch length.
    epoch_length: conint(ge=0, le=18446744073709551615) = None
    # Options for epoch sync.
    epoch_sync: EpochSyncConfig = None
    # Graceful shutdown at expected block height.
    expected_shutdown: MutableConfigValue = None
    # Garbage collection configuration.
    gc: GCConfig = None
    # Expected increase of header head height per second during header sync
    header_sync_expected_height_per_second: conint(ge=0, le=18446744073709551615) = None
    # How much time to wait after initial header sync
    header_sync_initial_timeout: conlist(conint(ge=0, le=18446744073709551615), min_length=2, max_length=2) = None
    # How much time to wait after some progress is made in header sync
    header_sync_progress_timeout: conlist(conint(ge=0, le=18446744073709551615), min_length=2, max_length=2) = None
    # How much time to wait before banning a peer in header sync if sync is too slow
    header_sync_stall_ban_timeout: conlist(conint(ge=0, le=18446744073709551615), min_length=2, max_length=2) = None
    # Period between logging summary information.
    log_summary_period: conlist(conint(ge=0, le=18446744073709551615), min_length=2, max_length=2) = None
    # Enable coloring of the logs
    log_summary_style: LogSummaryStyle = None
    # Maximum wait for approvals before producing block.
    max_block_production_delay: conlist(conint(ge=0, le=18446744073709551615), min_length=2, max_length=2) = None
    # Maximum duration before skipping given height.
    max_block_wait_delay: conlist(conint(ge=0, le=18446744073709551615), min_length=2, max_length=2) = None
    # Max burnt gas per view method.  If present, overrides value stored in
    # genesis file.  The value only affects the RPCs without influencing the
    # protocol thus changing it per-node doesn’t affect the blockchain.
    max_gas_burnt_view: NearGas | None = None
    # Minimum duration before producing block.
    min_block_production_delay: conlist(conint(ge=0, le=18446744073709551615), min_length=2, max_length=2) = None
    # Minimum number of peers to start syncing.
    min_num_peers: conint(ge=0, le=4294967295) = None
    # Number of block producer seats
    num_block_producer_seats: conint(ge=0, le=18446744073709551615) = None
    # Maximum size of state witnesses in the OrphanStateWitnessPool.
    # 
    # We keep only orphan witnesses which are smaller than this size.
    # This limits the maximum memory usage of OrphanStateWitnessPool.
    orphan_state_witness_max_size: conint(ge=0, le=18446744073709551615) = None
    # OrphanStateWitnessPool keeps instances of ChunkStateWitness which can't be processed
    # because the previous block isn't available. The witnesses wait in the pool until the
    # required block appears. This variable controls how many witnesses can be stored in the pool.
    orphan_state_witness_pool_size: conint(ge=0, le=4294967295) = None
    # Limit the time of adding transactions to a chunk.
    # A node produces a chunk by adding transactions from the transaction pool until
    # some limit is reached. This time limit ensures that adding transactions won't take
    # longer than the specified duration, which helps to produce the chunk quickly.
    produce_chunk_add_transactions_time_limit: str = None
    # Produce empty blocks, use `false` for testing.
    produce_empty_blocks: bool = None
    # Determines whether client should exit if the protocol version is not supported
    # for the next or next next epoch.
    protocol_version_check: ProtocolVersionCheckConfig = None
    resharding_config: MutableConfigValue = None
    # Listening rpc port for status.
    rpc_addr: str | None = None
    # Save observed instances of invalid ChunkStateWitness to the database in DBCol::InvalidChunkStateWitnesses.
    # Saving invalid witnesses is useful for analysis and debugging.
    # This option can cause extra load on the database and is not recommended for production use.
    save_invalid_witnesses: bool = None
    # Save observed instances of ChunkStateWitness to the database in DBCol::LatestChunkStateWitnesses.
    # Saving the latest witnesses is useful for analysis and debugging.
    # This option can cause extra load on the database and is not recommended for production use.
    save_latest_witnesses: bool = None
    # Whether to persist state changes on disk or not.
    save_state_changes: bool = None
    # save_trie_changes should be set to true iff
    # - archive if false - non-archival nodes need trie changes to perform garbage collection
    # - archive is true, cold_store is configured and migration to split_storage is finished - node
    # working in split storage mode needs trie changes in order to do garbage collection on hot.
    save_trie_changes: bool = None
    # Whether to persist transaction outcomes to disk or not.
    save_tx_outcomes: bool = None
    # Whether to persist partial chunk parts for untracked shards or not.
    save_untracked_partial_chunks_parts: bool = None
    # Skip waiting for sync (for testing or single node testnet).
    skip_sync_wait: bool = None
    # Number of threads for StateRequestActor pool.
    state_request_server_threads: conint(ge=0, le=4294967295) = None
    # Number of seconds between state requests for view client.
    # Throttling window for state requests (headers and parts).
    state_request_throttle_period: conlist(conint(ge=0, le=18446744073709551615), min_length=2, max_length=2) = None
    # Maximum number of state requests served per throttle period
    state_requests_per_throttle_period: conint(ge=0, le=4294967295) = None
    # Options for syncing state.
    state_sync: StateSyncConfig = None
    # Whether to use the State Sync mechanism.
    # If disabled, the node will do Block Sync instead of State Sync.
    state_sync_enabled: bool = None
    # Additional waiting period after a failed request to external storage
    state_sync_external_backoff: conlist(conint(ge=0, le=18446744073709551615), min_length=2, max_length=2) = None
    # How long to wait for a response from centralized state sync
    state_sync_external_timeout: conlist(conint(ge=0, le=18446744073709551615), min_length=2, max_length=2) = None
    # How long to wait for a response from p2p state sync
    state_sync_p2p_timeout: conlist(conint(ge=0, le=18446744073709551615), min_length=2, max_length=2) = None
    # How long to wait after a failed state sync request
    state_sync_retry_backoff: conlist(conint(ge=0, le=18446744073709551615), min_length=2, max_length=2) = None
    # How often to check that we are not out of sync.
    sync_check_period: conlist(conint(ge=0, le=18446744073709551615), min_length=2, max_length=2) = None
    # Sync height threshold: below this difference in height don't start syncing.
    sync_height_threshold: conint(ge=0, le=18446744073709551615) = None
    # Maximum number of block requests to send to peers to sync
    sync_max_block_requests: conint(ge=0, le=4294967295) = None
    # While syncing, how long to check for each step.
    sync_step_period: conlist(conint(ge=0, le=18446744073709551615), min_length=2, max_length=2) = None
    tracked_shards_config: TrackedShardsConfig = None
    # Limit of the size of per-shard transaction pool measured in bytes. If not set, the size
    # will be unbounded.
    transaction_pool_size_limit: conint(ge=0, le=18446744073709551615) | None = None
    transaction_request_handler_threads: conint(ge=0, le=4294967295) = None
    # Upper bound of the byte size of contract state that is still viewable. None is no limit
    trie_viewer_state_size_limit: conint(ge=0, le=18446744073709551615) | None = None
    # Time to persist Accounts Id in the router without removing them.
    ttl_account_id_router: conlist(conint(ge=0, le=18446744073709551615), min_length=2, max_length=2) = None
    # If the node is not a chunk producer within that many blocks, then route
    # to upcoming chunk producers.
    tx_routing_height_horizon: conint(ge=0, le=18446744073709551615) = None
    # Version of the binary.
    version: Version = None
    # Number of threads for ViewClientActor pool.
    view_client_threads: conint(ge=0, le=4294967295) = None



from near_jsonrpc_models.near_token import NearToken
from pydantic import BaseModel
from pydantic import conint


class GasKeyInfo(BaseModel):
    balance: NearToken
    num_nonces: conint(ge=0, le=65535)



"""Costs associated with an object that can only be sent over the network (and executed
by the receiver).
NOTE: `send_sir` or `send_not_sir` fees are usually burned when the item is being created.
And `execution` fee is burned when the item is being executed."""

from near_jsonrpc_models.near_gas import NearGas
from pydantic import BaseModel


class Fee(BaseModel):
    # Fee for executing the object.
    execution: NearGas
    # Fee for sending an object potentially across the shards.
    send_not_sir: NearGas
    # Fee for sending an object from the sender to itself, guaranteeing that it does not leave
    # the shard.
    send_sir: NearGas



from near_jsonrpc_models.internal_error import InternalError
from near_jsonrpc_models.rpc_request_validation_error_kind import RpcRequestValidationErrorKind
from near_jsonrpc_models.rpc_state_changes_error import RpcStateChangesError
from pydantic import BaseModel
from pydantic import RootModel
from typing import Literal
from typing import Union


class ErrorWrapperForRpcStateChangesErrorRequestValidationError(BaseModel):
    cause: RpcRequestValidationErrorKind
    name: Literal['REQUEST_VALIDATION_ERROR']

class ErrorWrapperForRpcStateChangesErrorHandlerError(BaseModel):
    cause: RpcStateChangesError
    name: Literal['HANDLER_ERROR']

class ErrorWrapperForRpcStateChangesErrorInternalError(BaseModel):
    cause: InternalError
    name: Literal['INTERNAL_ERROR']

class ErrorWrapperForRpcStateChangesError(RootModel[Union[ErrorWrapperForRpcStateChangesErrorRequestValidationError, ErrorWrapperForRpcStateChangesErrorHandlerError, ErrorWrapperForRpcStateChangesErrorInternalError]]):
    pass




from near_jsonrpc_models.internal_error import InternalError
from near_jsonrpc_models.rpc_light_client_next_block_error import RpcLightClientNextBlockError
from near_jsonrpc_models.rpc_request_validation_error_kind import RpcRequestValidationErrorKind
from pydantic import BaseModel
from pydantic import RootModel
from typing import Literal
from typing import Union


class ErrorWrapperForRpcLightClientNextBlockErrorRequestValidationError(BaseModel):
    cause: RpcRequestValidationErrorKind
    name: Literal['REQUEST_VALIDATION_ERROR']

class ErrorWrapperForRpcLightClientNextBlockErrorHandlerError(BaseModel):
    cause: RpcLightClientNextBlockError
    name: Literal['HANDLER_ERROR']

class ErrorWrapperForRpcLightClientNextBlockErrorInternalError(BaseModel):
    cause: InternalError
    name: Literal['INTERNAL_ERROR']

class ErrorWrapperForRpcLightClientNextBlockError(RootModel[Union[ErrorWrapperForRpcLightClientNextBlockErrorRequestValidationError, ErrorWrapperForRpcLightClientNextBlockErrorHandlerError, ErrorWrapperForRpcLightClientNextBlockErrorInternalError]]):
    pass




from pydantic import BaseModel


class RpcClientError(Exception):
    """Base error for all NEAR client related failures."""
    pass


class RpcTransportError(RpcClientError):
    """Network-level errors (timeout, DNS, connection, etc)."""
    pass


class RpcHttpError(RpcClientError):
    """Non-200 HTTP responses."""

    def __init__(self, status_code: int, body: str | None = None):
        self.status_code = status_code
        self.body = body
        super().__init__(f"HTTP error {status_code}")


class RpcError(RpcClientError):
    """JSON-RPC error object wrapping the Pydantic error model."""

    def __init__(self, error: BaseModel | str):
        self.error = error

        if isinstance(error, BaseModel):
            super().__init__(getattr(error, "message", "RPC Error"))
        else:
            super().__init__(error)


class RpcTimeoutError(RpcClientError):
    """Timeout Error"""

    def __init__(self):
        super().__init__("Timeout Error")



from near_jsonrpc_models.account_id import AccountId
from near_jsonrpc_models.block_reference import BlockReference
from near_jsonrpc_models.crypto_hash import CryptoHash
from near_jsonrpc_models.function_call_error import FunctionCallError
from near_jsonrpc_models.global_contract_identifier import GlobalContractIdentifier
from near_jsonrpc_models.public_key import PublicKey
from near_jsonrpc_models.shard_id import ShardId
from pydantic import BaseModel
from pydantic import RootModel
from pydantic import conint
from typing import Literal
from typing import Union


class RpcQueryErrorNoSyncedBlocks(BaseModel):
    name: Literal['NO_SYNCED_BLOCKS']

class RpcQueryErrorUnavailableShardInfo(BaseModel):
    requested_shard_id: ShardId

class RpcQueryErrorUnavailableShard(BaseModel):
    info: RpcQueryErrorUnavailableShardInfo
    name: Literal['UNAVAILABLE_SHARD']

class RpcQueryErrorGarbageCollectedBlockInfo(BaseModel):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)

class RpcQueryErrorGarbageCollectedBlock(BaseModel):
    info: RpcQueryErrorGarbageCollectedBlockInfo
    name: Literal['GARBAGE_COLLECTED_BLOCK']

class RpcQueryErrorUnknownBlockInfo(BaseModel):
    block_reference: BlockReference

class RpcQueryErrorUnknownBlock(BaseModel):
    info: RpcQueryErrorUnknownBlockInfo
    name: Literal['UNKNOWN_BLOCK']

class RpcQueryErrorInvalidAccountInfo(BaseModel):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)
    requested_account_id: AccountId

class RpcQueryErrorInvalidAccount(BaseModel):
    info: RpcQueryErrorInvalidAccountInfo
    name: Literal['INVALID_ACCOUNT']

class RpcQueryErrorUnknownAccountInfo(BaseModel):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)
    requested_account_id: AccountId

class RpcQueryErrorUnknownAccount(BaseModel):
    info: RpcQueryErrorUnknownAccountInfo
    name: Literal['UNKNOWN_ACCOUNT']

class RpcQueryErrorNoContractCodeInfo(BaseModel):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)
    contract_account_id: AccountId

class RpcQueryErrorNoContractCode(BaseModel):
    info: RpcQueryErrorNoContractCodeInfo
    name: Literal['NO_CONTRACT_CODE']

class RpcQueryErrorTooLargeContractStateInfo(BaseModel):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)
    contract_account_id: AccountId

class RpcQueryErrorTooLargeContractState(BaseModel):
    info: RpcQueryErrorTooLargeContractStateInfo
    name: Literal['TOO_LARGE_CONTRACT_STATE']

class RpcQueryErrorUnknownAccessKeyInfo(BaseModel):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)
    public_key: PublicKey

class RpcQueryErrorUnknownAccessKey(BaseModel):
    info: RpcQueryErrorUnknownAccessKeyInfo
    name: Literal['UNKNOWN_ACCESS_KEY']

class RpcQueryErrorUnknownGasKeyInfo(BaseModel):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)
    public_key: PublicKey

class RpcQueryErrorUnknownGasKey(BaseModel):
    info: RpcQueryErrorUnknownGasKeyInfo
    name: Literal['UNKNOWN_GAS_KEY']

class RpcQueryErrorContractExecutionErrorInfo(BaseModel):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)
    error: FunctionCallError
    vm_error: str

class RpcQueryErrorContractExecutionError(BaseModel):
    info: RpcQueryErrorContractExecutionErrorInfo
    name: Literal['CONTRACT_EXECUTION_ERROR']

class RpcQueryErrorNoGlobalContractCodeInfo(BaseModel):
    block_hash: CryptoHash
    block_height: conint(ge=0, le=18446744073709551615)
    identifier: GlobalContractIdentifier

class RpcQueryErrorNoGlobalContractCode(BaseModel):
    info: RpcQueryErrorNoGlobalContractCodeInfo
    name: Literal['NO_GLOBAL_CONTRACT_CODE']

class RpcQueryErrorInternalErrorInfo(BaseModel):
    error_message: str

class RpcQueryErrorInternalError(BaseModel):
    info: RpcQueryErrorInternalErrorInfo
    name: Literal['INTERNAL_ERROR']

class RpcQueryError(RootModel[Union[RpcQueryErrorNoSyncedBlocks, RpcQueryErrorUnavailableShard, RpcQueryErrorGarbageCollectedBlock, RpcQueryErrorUnknownBlock, RpcQueryErrorInvalidAccount, RpcQueryErrorUnknownAccount, RpcQueryErrorNoContractCode, RpcQueryErrorTooLargeContractState, RpcQueryErrorUnknownAccessKey, RpcQueryErrorUnknownGasKey, RpcQueryErrorContractExecutionError, RpcQueryErrorNoGlobalContractCode, RpcQueryErrorInternalError]]):
    pass




"""See crate::types::StateChangeCause for details."""

from near_jsonrpc_models.crypto_hash import CryptoHash
from pydantic import BaseModel
from pydantic import RootModel
from typing import Literal
from typing import Union


class StateChangeCauseViewNotWritableToDisk(BaseModel):
    type: Literal['not_writable_to_disk']

class StateChangeCauseViewInitialState(BaseModel):
    type: Literal['initial_state']

class StateChangeCauseViewTransactionProcessing(BaseModel):
    tx_hash: CryptoHash
    type: Literal['transaction_processing']

class StateChangeCauseViewActionReceiptProcessingStarted(BaseModel):
    receipt_hash: CryptoHash
    type: Literal['action_receipt_processing_started']

class StateChangeCauseViewActionReceiptGasReward(BaseModel):
    receipt_hash: CryptoHash
    type: Literal['action_receipt_gas_reward']

class StateChangeCauseViewReceiptProcessing(BaseModel):
    receipt_hash: CryptoHash
    type: Literal['receipt_processing']

class StateChangeCauseViewPostponedReceipt(BaseModel):
    receipt_hash: CryptoHash
    type: Literal['postponed_receipt']

class StateChangeCauseViewUpdatedDelayedReceipts(BaseModel):
    type: Literal['updated_delayed_receipts']

class StateChangeCauseViewValidatorAccountsUpdate(BaseModel):
    type: Literal['validator_accounts_update']

class StateChangeCauseViewMigration(BaseModel):
    type: Literal['migration']

class StateChangeCauseViewBandwidthSchedulerStateUpdate(BaseModel):
    type: Literal['bandwidth_scheduler_state_update']

class StateChangeCauseView(RootModel[Union[StateChangeCauseViewNotWritableToDisk, StateChangeCauseViewInitialState, StateChangeCauseViewTransactionProcessing, StateChangeCauseViewActionReceiptProcessingStarted, StateChangeCauseViewActionReceiptGasReward, StateChangeCauseViewReceiptProcessing, StateChangeCauseViewPostponedReceipt, StateChangeCauseViewUpdatedDelayedReceipts, StateChangeCauseViewValidatorAccountsUpdate, StateChangeCauseViewMigration, StateChangeCauseViewBandwidthSchedulerStateUpdate]]):
    pass




from near_jsonrpc_models.internal_error import InternalError
from near_jsonrpc_models.rpc_request_validation_error_kind import RpcRequestValidationErrorKind
from near_jsonrpc_models.rpc_transaction_error import RpcTransactionError
from pydantic import BaseModel
from pydantic import RootModel
from typing import Literal
from typing import Union


class ErrorWrapperForRpcTransactionErrorRequestValidationError(BaseModel):
    cause: RpcRequestValidationErrorKind
    name: Literal['REQUEST_VALIDATION_ERROR']

class ErrorWrapperForRpcTransactionErrorHandlerError(BaseModel):
    cause: RpcTransactionError
    name: Literal['HANDLER_ERROR']

class ErrorWrapperForRpcTransactionErrorInternalError(BaseModel):
    cause: InternalError
    name: Literal['INTERNAL_ERROR']

class ErrorWrapperForRpcTransactionError(RootModel[Union[ErrorWrapperForRpcTransactionErrorRequestValidationError, ErrorWrapperForRpcTransactionErrorHandlerError, ErrorWrapperForRpcTransactionErrorInternalError]]):
    pass

